summaryrefslogtreecommitdiffstats
path: root/krita/ui/kis_dlg_adj_layer_props.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /krita/ui/kis_dlg_adj_layer_props.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'krita/ui/kis_dlg_adj_layer_props.h')
-rw-r--r--krita/ui/kis_dlg_adj_layer_props.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/krita/ui/kis_dlg_adj_layer_props.h b/krita/ui/kis_dlg_adj_layer_props.h
index 783e65e5..de848002 100644
--- a/krita/ui/kis_dlg_adj_layer_props.h
+++ b/krita/ui/kis_dlg_adj_layer_props.h
@@ -22,14 +22,14 @@
#include <kdialogbase.h>
class KisFilter;
-class QIconViewItem;
-class QLabel;
-class QHBoxLayout;
+class TQIconViewItem;
+class TQLabel;
+class TQHBoxLayout;
class KisPreviewWidget;
class KisFiltersListView;
class KisFilterConfiguration;
class KisImage;
-class QGroupBox;
+class TQGroupBox;
/**
* Create a new adjustment layer.
@@ -38,6 +38,7 @@ class KisDlgAdjLayerProps : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -49,21 +50,21 @@ public:
* @param caption the caption for the dialog -- create or properties
* @param create if true, set the dialog up for creating a new adj. layer, if false, edit the
* propeties of the current adj. layer
* @param parent the widget parent of this dialog
* @param name the QObject name, if any
*/
KisDlgAdjLayerProps(KisAdjustmentLayerSP layer,
- const QString & layerName,
- const QString & caption,
- QWidget *parent = 0,
+ const TQString & layerName,
+ const TQString & caption,
+ TQWidget *tqparent = 0,
const char *name = 0);
KisFilterConfiguration * filterConfiguration() const;
- QString layerName() const;
+ TQString layerName() const;
protected slots:
- void slotNameChanged( const QString & );
+ void slotNameChanged( const TQString & );
void slotConfigChanged();
void refreshPreview();
@@ -49,21 +50,21 @@ public:
* @param create if true, set the dialog up for creating a new adj. layer, if false, edit the
* propeties of the current adj. layer
- * @param parent the widget parent of this dialog
- * @param name the QObject name, if any
+ * @param tqparent the widget tqparent of this dialog
+ * @param name the TQObject name, if any
*/
KisDlgAdjLayerProps(KisAdjustmentLayerSP layer,